@@ -17,11 +17,16 @@ class Target:
     def __init__(self, input: str):
         prepared_input = input.strip()
         if prepared_input.lower() in (
-            "username",
-            "password",
+            "brand",
+            "cardholder",
+            "code",
+            "expiry",
             "menu",
-            "totp",
             "notes",
+            "number",
+            "password",
+            "totp",
+            "username",
         ) or prepared_input.lower().startswith("uri"):
             self.__value = prepared_input.lower()
         else:
@@ -55,6 +60,11 @@ class Targets:
     USERNAME = Target("username")
     PASSWORD = Target("password")
     TOTP = Target("totp")
+    NUMBER = Target("number")
+    CARDHOLDER = Target("cardholder")
+    BRAND = Target("brand")
+    EXPIRY = Target("expiry")
+    CODE = Target("code")
     NOTES = Target("notes")
     MENU = Target("menu")
 
